django-awl
**********

Yet another catch-all of tools for django.  Includes utilities for admin,
context processors, CSS colours, view and model mixins, template tags and
unit testing.


Installation
============

.. code-block:: bash

    $ pip install django-awl

Supports
========

django-awl has been tested with:

* Django 3.2 using Python 3.7, 3.8, 3.9, 3.10
* Django 4.0 using Python 3.8, 3.9, 3.10
* Django 4.1 using Python 3.8, 3.9, 3.10, 3.11


Docs & Source
=============

Docs: http://django-awl.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/django-awl
